@@ -86,8 +86,8 @@ sub build_proxy {
 # METHODS
 
 sub __handle__unbox {
-  my ($self) = @_;
-  return $self->{value};
+  my ($self, $code, @args) = @_;
+  return $code ? $self->$code(@args)->{value} : $self->{value};
 }
 
 1;
@@ -145,10 +145,12 @@ This package provides the following methods:
 
 =head2 unbox
 
-  unbox() (Any)
+  unbox(Str $method, Any @args) (Any)
 
 The unbox method returns the un-boxed underlying object. This is a virtual
-method that dispatches to C<__handle__unbox>.
+method that dispatches to C<__handle__unbox>. This method supports dispatching,
+i.e. providing a method name and arguments whose return value will be acted on
+by this method.
 
 I<Since C<0.01>>
 
@@ -164,4 +166,16 @@ I<Since C<0.01>>
 
 =back
 
+=over 4
+
+=item unbox example 2
+
+  # given: synopsis;
+
+  my $unbox = $box->unbox('count');
+
+  # 0
+
+=back
+
 =cut
\ No newline at end of file
