@@ -16,7 +16,6 @@ with 'Venus::Role::Explainable';
 
 use overload (
   '""' => 'explain',
-  '.' => sub{$_[0]->value . "$_[1]"},
   'eq' => sub{$_[0]->value eq "$_[1]"},
   'ne' => sub{$_[0]->value ne "$_[1]"},
   'qr' => sub{qr/@{[quotemeta($_[0]->value)]}/},
@@ -26,6 +25,18 @@ use overload (
 
 # METHODS
 
+sub assertion {
+  my ($self) = @_;
+
+  my $assert = $self->SUPER::assertion;
+
+  $assert->constraints->clear;
+
+  $assert->constraint('string', true);
+
+  return $assert;
+}
+
 sub absolute {
   my ($self) = @_;
 
@@ -178,6 +189,14 @@ sub is_relative {
   return int!$self->is_absolute;
 }
 
+sub lines {
+  my ($self, $separator, $binmode) = @_;
+
+  $separator //= "\n";
+
+  return [split /$separator/, $binmode ? $self->read($binmode) : $self->read];
+}
+
 sub lineage {
   my ($self) = @_;
 
@@ -691,6 +710,7 @@ I<Since C<0.01>>
   #   bless({ value => "t/data/planets/mars" }, "Venus::Path"),
   #   bless({ value => "t/data/planets/mercury" }, "Venus::Path"),
   #   bless({ value => "t/data/planets/neptune" }, "Venus::Path"),
+  #   bless({ value => "t/data/planets/planet9" }, "Venus::Path"),
   #   bless({ value => "t/data/planets/pluto" }, "Venus::Path"),
   #   bless({ value => "t/data/planets/saturn" }, "Venus::Path"),
   #   bless({ value => "t/data/planets/uranus" }, "Venus::Path"),
@@ -874,6 +894,7 @@ I<Since C<0.01>>
   #   bless({ value => "t/data/planets/mars" }, "Venus::Path"),
   #   bless({ value => "t/data/planets/mercury" }, "Venus::Path"),
   #   bless({ value => "t/data/planets/neptune" }, "Venus::Path"),
+  #   bless({ value => "t/data/planets/planet9" }, "Venus::Path"),
   #   bless({ value => "t/data/planets/pluto" }, "Venus::Path"),
   #   bless({ value => "t/data/planets/saturn" }, "Venus::Path"),
   #   bless({ value => "t/data/planets/uranus" }, "Venus::Path"),
@@ -912,6 +933,7 @@ I<Since C<0.01>>
   #   bless({ value => "t/data/planets/mars" }, "Venus::Path"),
   #   bless({ value => "t/data/planets/mercury" }, "Venus::Path"),
   #   bless({ value => "t/data/planets/neptune" }, "Venus::Path"),
+  #   bless({ value => "t/data/planets/planet9" }, "Venus::Path"),
   #   bless({ value => "t/data/planets/pluto" }, "Venus::Path"),
   #   bless({ value => "t/data/planets/saturn" }, "Venus::Path"),
   #   bless({ value => "t/data/planets/uranus" }, "Venus::Path"),
@@ -980,6 +1002,7 @@ I<Since C<0.01>>
   #   bless({ value => "t/data/planets/mars" }, "Venus::Path"),
   #   bless({ value => "t/data/planets/mercury" }, "Venus::Path"),
   #   bless({ value => "t/data/planets/neptune" }, "Venus::Path"),
+  #   bless({ value => "t/data/planets/planet9" }, "Venus::Path"),
   #   bless({ value => "t/data/planets/pluto" }, "Venus::Path"),
   #   bless({ value => "t/data/planets/saturn" }, "Venus::Path"),
   #   bless({ value => "t/data/planets/uranus" }, "Venus::Path"),
@@ -1105,6 +1128,41 @@ I<Since C<0.01>>
 
 =cut
 
+=head2 lines
+
+  lines(Str|Regexp $separator, Str $binmode) (ArrayRef[Str])
+
+The lines method returns the list of lines from the underlying file. By default
+the file contents are separated by newline.
+
+I<Since C<1.23>>
+
+=over 4
+
+=item lines example 1
+
+  # given: synopsis;
+
+  my $lines = $path->child('mercury')->lines;
+
+  # ['mercury']
+
+=back
+
+=over 4
+
+=item lines example 2
+
+  # given: synopsis;
+
+  my $lines = $path->child('planet9')->lines($^O =~ /win32/i ? "\n" : "\r\n");
+
+  # ['planet', 'nine']
+
+=back
+
+=cut
+
 =head2 mkcall
 
   mkcall(Any @data) (Any)
@@ -1919,6 +1977,16 @@ B<example 1>
 
   # "t/data/planets"
 
+B<example 2>
+
+  # given: synopsis;
+
+  my $mercury = $path->child('mercury');
+
+  my $result = "$path, $path";
+
+  # "t/data/planets, t/data/planets"
+
 =back
 
 =over 4
