@@ -7,7 +7,17 @@ use warnings;
 
 use Venus::Role 'with';
 
-with 'Venus::Role::Proxyable';
+# AUDITS
+
+sub AUDIT {
+  my ($self, $from) = @_;
+
+  if (!$from->does('Venus::Role::Proxyable')) {
+    die "${self} requires ${from} to consume Venus::Role::Proxyable";
+  }
+
+  return $self;
+}
 
 # METHODS
 
@@ -28,7 +38,7 @@ sub build_proxy {
 # EXPORTS
 
 sub EXPORT {
-  ['AUTOLOAD', 'BUILDPROXY', 'build_proxy']
+  ['build_proxy']
 }
 
 1;
@@ -65,6 +75,7 @@ Pluggable Role for Perl 5
 
   use Venus::Class;
 
+  with 'Venus::Role::Proxyable';
   with 'Venus::Role::Pluggable';
 
   attr 'secret';
@@ -81,12 +92,4 @@ Pluggable Role for Perl 5
 
 This package provides a mechanism for dispatching to plugin classes.
 
-=cut
-
-=head1 INTEGRATES
-
-This package integrates behaviors from:
-
-L<Venus::Role::Proxyable>
-
 =cut
\ No newline at end of file
